/*
 * converter.h
 *
 *  Created on: Jan 15, 2015
 *      Author: tnemeth
 */

#ifndef CONVERTER_H_
#define CONVERTER_H_

#include "convrules.h"
#include "codecregistry.h"

namespace imconvertts {

/**
 * Return values for checkAndConvertTS
 */
typedef enum {
	/** Pixel data was successfully converted from one TS to another */
	CONVERT_TS_OK,
	/** No conversion needed (either disabled or other reason) */
	CONVERT_TS_OK_NOT_NEEDED,
	/** Conversion has not enough gain */
	CONVERT_TS_NO_GAIN,
	/** An error occurred during conversion */
	CONVERT_TS_ERROR
} CONVERT_TS_RESULT;


class Converter {
	private:
		CodecRegistry m_codecRegistry;
		RuleSet m_ruleSet;
		Sint32 m_gainRate;

		bool m_verbose;

	public:

		Converter( RULE_SET_TYPE ruleSetType, Sint32 gainRate );
		~Converter();

		/**
		 * Tries to convert dataset to the requested transfer syntax. If the dataset contains no pixel data,
		 * then it will be converted to imagelessXfer or left as is when imagelessXfer is 'Unknown'.
		 * When applying imagelessXfer, outXfer will also be updated
		 *
		 * @param dataset        the dataset to convert
		 * @param outXfer        the requested TS (and returns the actual TS selected)
		 * @param imagelessXfer  optional TS for imageless objects
		 * @return conversion result code
		 */
		CONVERT_TS_RESULT convert( DcmDataset * dataset, E_TransferSyntax & outXfer, E_TransferSyntax imagelessXfer = EXS_Unknown );

		inline void setVerbose( bool verboseFlag ) {
			m_verbose = verboseFlag;
		}
};

}


#endif /* CONVERTER_H_ */
